pub struct SecretString<T>(/* private fields */)
where
T: AsRef<str>;Expand description
A string wrapper that hides its contents when printed or formatted for debugging.
It WILL however serialize the value when using serde serialization/deserialization.
Examples
use secret_string::SecretString;
let secret = SecretString::new("my_secret_password");
assert_eq!(format!("{}", secret), "******************");
assert_eq!(format!("{:?}", secret), "SecretString(******************)");
assert_eq!(secret.value(), "my_secret_password");Implementations
Sourceimpl<T: AsRef<str>> SecretString<T>
impl<T: AsRef<str>> SecretString<T>
pub fn new(s: T) -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn as_stars(&self) -> String
pub fn as_stars(&self) -> String
Returns a string of asterisks (*) with the same length as the secret string.
Sourcepub fn as_stars_with_with_len(&self, len: usize) -> String
pub fn as_stars_with_with_len(&self, len: usize) -> String
In case you don’t want to show the length of the secret